# REL03: How do you design your workload service architecture?

## References

- [AWS REL03](https://docs.aws.amazon.com/wellarchitected/latest/framework/rel-03.html)

## Date

2025-11-27

## Focus Area

Workload Architecture

## Tổng quan

REL03 tập trung vào service architecture design.

## Best Practices

### REL03-BP01: Choose how to segment your workload
Microservices vs monolith.

### REL03-BP02: Build services focused on specific business domains
Domain-driven design.

### REL03-BP03: Provide service contracts per API
API contracts.

## Checklist

- [ ] Service boundaries defined
- [ ] APIs documented
- [ ] Service contracts established
